@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "1-Jan-26"
+#define SND_DATE "5-Feb-26"
 #ifndef SND_VERSION
-#define SND_VERSION "26.0"
+#define SND_VERSION "26.1"
 #endif
 #define SND_MAJOR_VERSION "26"
-#define SND_MINOR_VERSION "0"
+#define SND_MINOR_VERSION "1"
 
 #endif
